summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/cli.rs7
-rw-r--r--src/common/input/options.rs4
2 files changed, 5 insertions, 6 deletions
diff --git a/src/cli.rs b/src/cli.rs
index 870af1d14..6ab33d455 100644
--- a/src/cli.rs
+++ b/src/cli.rs
@@ -1,4 +1,5 @@
use super::common::utils::consts::{ZELLIJ_CONFIG_DIR_ENV, ZELLIJ_CONFIG_FILE_ENV};
+use crate::common::input::options::Options;
use serde::{Deserialize, Serialize};
use std::path::PathBuf;
use structopt::StructOpt;
@@ -41,11 +42,7 @@ pub struct CliArgs {
pub enum ConfigCli {
/// Change the behaviour of zellij
#[structopt(name = "options")]
- Options {
- #[structopt(long)]
- /// Allow plugins to use a more compatible font type
- simplified_ui: bool,
- },
+ Options(Options),
#[structopt(name = "generate-completion")]
GenerateCompletion { shell: String },
diff --git a/src/common/input/options.rs b/src/common/input/options.rs
index 4c2dd861d..3ff2fd8e5 100644
--- a/src/common/input/options.rs
+++ b/src/common/input/options.rs
@@ -1,10 +1,12 @@
use serde::{Deserialize, Serialize};
+use structopt::StructOpt;
-#[derive(Clone, Default, Debug, PartialEq, Deserialize, Serialize)]
+#[derive(Clone, Default, Debug, PartialEq, Deserialize, Serialize, StructOpt)]
/// Options that can be set either through the config file,
/// or cli flags
pub struct Options {
/// Allow plugins to use a more compatible font type
+ #[structopt(long)]
pub simplified_ui: bool,
}